@@ -48,9 +48,9 @@ def get_synchronization_tasks(object_name):
               'method': Object('create_binhost_data()')
              },
              {
-              'name': 'check_if_update_by_branch',
-              'method': Object('turn_off_migration_if_needed()'),
-              'condition': lambda Get, GetBool: (Get('cl_check_update_level')  == 'on')
+              'name': 'perform_migration_system_pre_check',
+              'method': Object('perform_migration_system_pre_check()'),
+              'condition': lambda Get, GetBool: (Get('cl_update_ignore_level')  == 'off')
              },
              # проверить валиден ли текущий хост
              {'name': 'check_current_binhost',
@@ -60,7 +60,8 @@ def get_synchronization_tasks(object_name):
               'condition': lambda GetBool, Get: (
                     not GetBool('update.cl_update_binhost_recheck_set') and
                     Get('update.cl_update_sync_rep') and
-                    Get('update.cl_update_binhost'))
+                    Get('update.cl_update_binhost') and 
+                    Get('update.cl_update_use_migration_host') == 'off')
              },
              {'name': 'not_use_search:failed_base_binhost',
               'error': __("Failed to use base binhost"),
@@ -78,7 +79,7 @@ def get_synchronization_tasks(object_name):
               'tasks': [
                  # найти лучший сервер обновлений
                  {'name': 'detect_best_binhost',
-                  'method': Object(f'detect_best_binhost({object_name.lower()}.cl_check_update_level)'),
+                  'method': Object(f'detect_best_binhost({object_name.lower()}.cl_update_ignore_level)'),
                   'essential': False,
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
                              (~AllTasks.success_one_of("check_current_binhost") |
